==> slds-button-0.4.0.tgz: package/button.spec.md <==
# Specification

## Overview

A button is a call to action that allows people to make a selection, navigate, send data, or take other types of actions.

This specification is an extension of [SDS Button Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md)

### Anatomy and Appearance

#### DOM Structure

[SDS Button - DOM Structure &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#dom-structure)

## API

### Properties & Attributes

[SDS Button - Properties & Attributes &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#properties--attributes)

Below are the list of attributes for `slds-button` in addition to existing ones for`sds-button`.

|Attribute |Type |Values| Default Value |Description |
|- |- |- |- |- |
|`size` |`enum`| `default/stretch` |`default` |Determines the size of the button |
|`variant` |`enum`| `bare/nuetral/brand/brand-outline/destructive/success/text-destructive` |`bare` |Determines the type of the button |

#### Styling Hooks

|Property Name |CSS Property |Fallback Value |Description |
|- |- |- |- |
|`--slds-s-button-spacing-inline` |`padding-inline` |`1rem` |Default inline padding for buttons|
|`--slds-s-button-font-lineheight` |`line-height` |`1.875rem` |Default line-height for buttons|
|`--slds-c-button-neutral-color-background` |`background-color` |`#fff` |Default background color for neutral buttons|
|`--slds-c-button-neutral-color-background-hover` |`background-color` |`#f3f3f3` |Default background color for neutral buttons on hover|
|`--slds-c-button-neutral-color-background-active` |`background-color` |`#e5e5e5` |Default background color for neutral buttons on active|
|`--slds-c-button-neutral-color-border` |`border-color` |`#c9c9cb` |Default border color for neutral buttons|
|`--slds-c-button-neutral-color-border-hover` |`border-color` |`#c9c9cb` |Default border color for neutral buttons on hover|
|`--slds-c-button-neutral-color-border-active` |`border-color` |`#c9c9cb` |Default border color for neutral buttons on active|
|`--slds-c-button-neutral-text-color` |`color` |`#0b5cab` |Default text color for neutral buttons|
|`--slds-c-button-neutral-text-color-hover` |`color` |`#0b5cab` |Default text color for neutral buttons on hover|
|`--slds-c-button-neutral-text-color-active` |`color` |`#0b5cab` |Default text color for neutral buttons on active|


## Accessibility

[SDS Button - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#accessibility)

## Internationalization

[SDS Button - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#internationalization)

## Test Plan

[SDS Button - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#test-plan)

==> slds-button-0.8.0.tgz: package/button.spec.md <==
# Specification

## Overview

A button is a call to action that allows people to make a selection, navigate, send data, or take other types of actions.

This specification is an extension of [SDS Button Specification &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md)

### Anatomy and Appearance

#### DOM Structure

[SDS Button - DOM Structure &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#dom-structure)

## API

### Properties & Attributes

[SDS Button - Properties & Attributes &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#properties--attributes)

Below are the list of attributes for `slds-button` in addition to existing ones for`sds-button`.

|Attribute |Type |Values| Default Value |Description |
|- |- |- |- |- |
|`size` |`enum`| `default/stretch` |`default` |Determines the size of the button |
|`variant` |`enum`| `bare/nuetral/brand/brand-outline/destructive/success/text-destructive` |`bare` |Determines the type of the button |

#### Styling Hooks

|Property Name |CSS Property |Fallback Value |Description |
|- |- |- |- |
|`--slds-s-button-spacing-inline` |`padding-inline` |`1rem` |Default inline padding for buttons|
|`--slds-s-button-font-lineheight` |`line-height` |`1.875rem` |Default line-height for buttons|
|`--slds-c-button-neutral-color-background` |`background-color` |`#fff` |Default background color for neutral buttons|
|`--slds-c-button-neutral-color-background-hover` |`background-color` |`#f3f3f3` |Default background color for neutral buttons on hover|
|`--slds-c-button-neutral-color-background-active` |`background-color` |`#e5e5e5` |Default background color for neutral buttons on active|
|`--slds-c-button-neutral-color-background-focus` |`background-color` |`#f3f3f3` |Default background color for neutral buttons on focus|
|`--slds-c-button-neutral-color-background-disabled` |`background-color` |`transparent` |Default background color for neutral buttons when disabled|
|`--slds-c-button-neutral-color-border` |`border-color` |`#c9c9cb` |Default border color for neutral buttons|
|`--slds-c-button-neutral-color-border-hover` |`border-color` |`#c9c9cb` |Default border color for neutral buttons on hover|
|`--slds-c-button-neutral-color-border-active` |`border-color` |`#0176d3` |Default border color for neutral buttons on active|
|`--slds-c-button-neutral-color-border-disabled` |`border-color` |`#e5e5e5` |Default border color for neutral buttons when disabled|
|`--slds-c-button-neutral-text-color` |`color` |`#0b5cab` |Default text color for neutral buttons|
|`--slds-c-button-neutral-text-color-hover` |`color` |`#001639` |Default text color for neutral buttons on hover|
|`--slds-c-button-neutral-text-color-active` |`color` |`#001639` |Default text color for neutral buttons on active|
|`--slds-c-button-neutral-text-color-focus` |`color` |`#001639` |Default text color for neutral buttons on focus|
|`--slds-c-button-neutral-text-color-disabled` |`color` |`#939393` |Default text color for neutral buttons when disabled|
|`--slds-c-button-neutral-shadow` |`box shadow color` |`none` |Default box shadow color for neutral buttons (Must be defined)|
|`--slds-c-button-neutral-shadow-focus` |`box shadow color` |`#0176d3 0 0 3px` |Default box shadow color for neutral buttons when focused|

## Accessibility

[SDS Button - Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#accessibility)

## Internationalization

[SDS Button - Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#internationalization)

## Test Plan

[SDS Button - Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/button/button.spec.md#test-plan)
